@@ -67,9 +67,7 @@ def format_full_name(first_name: str, last_name: str, max_length: int = 20) -> s
     return full_name
 
 
-def format_timedelta(
-    dt: timedelta, days_label: str = "d", hours_label: str = "h", minutes_label: str = "min", seconds_label: str = "s"
-) -> str:
+def format_timedelta(dt: timedelta, days_label: str = "d", hours_label: str = "h", minutes_label: str = "min", seconds_label: str = "s") -> str:
     """
     Formats timedelta to readable format, e.g. 1h30min15s.
     :param dt: timedelta
@@ -370,16 +368,7 @@ def format_table(  # noqa
     return "\n".join(lines3)
 
 
-def ucfirst(v: str) -> str:
-    """
-    Converts first character of the string to uppercase.
-    :param v: str
-    :return: str
-    """
-    return v[0:1].upper() + v[1:]
-
-
-ucfirst_lazy = lazy(ucfirst, str)
+capfirst_lazy = lazy(capfirst, str)
 
 
 def dec1(a: Union[float, int, Decimal, str]) -> Decimal:
@@ -502,7 +491,7 @@ def underscore_to_camel_case(s: str) -> str:
     """
     if s:
         p = s.split("_")
-        s = p[0] + "".join([ucfirst(w) for w in p[1:]])
+        s = p[0] + "".join([capfirst(w) or "" for w in p[1:]])
     return s
 
 
